Skip to content

functionControl internal option is documented but only the misspelled functonControl works #422

Description

@pvelesko

IGCInternalOptions.td:139 on master defines functonControl, while the comment on line 138 documents the option as -ze-intel-functionControl. The correctly spelled form is defined nowhere, and unknown internal options are accepted without a diagnostic, so it silently does nothing.

ocloc 26.27.39122.11, -device dg2. Still present on master at 321f361.

__attribute__((noinline)) int helper(global int *p, int i) { return p[i] * 3 + i; }
kernel void k(global int *o, global int *p) {
  int i = get_global_id(0);
  o[i] = helper(p, i) + helper(p, i + 1);
}
-internal_options resulting fc_dg2.bin
none 5736 bytes
-cl-intel-functonControl 1 5952 bytes
-cl-intel-functionControl 1 5736 bytes, byte identical to none

I have a patch adding the documented spelling as an alias so the existing one keeps working, and can open a PR.

Activity

Sign up for free to join this conversation on GitHub. Already have an account? Sign in to comment

Metadata

Metadata

Assignees

No one assigned

    Labels

    No labels
    No labels

    Type

    No type

    Projects

    No projects

      Milestone

      No milestone

      Relationships

      None yet

      Development

      No branches or pull requests

      Issue actions